# Changelog

<!--next-version-placeholder-->

## v2.1.0 (2023-01-06)
### Feature
* Wrapper function ([`fb33e19`](https://github.com/HLasse/TextDescriptives/commit/fb33e19e09b2551a049dccf42722d67f5c17199a))

### Fix
* Remove previously assigned extensions before extracting new metrics ([`1a7ca00`](https://github.com/HLasse/TextDescriptives/commit/1a7ca00559f1db0060cfcb0d0a120a1948d697c7))
* Remove doc extension instead of pipe component. TODO double check all assings are correct ([`bc32d47`](https://github.com/HLasse/TextDescriptives/commit/bc32d479da59bfb438bb860795ca56e02fc60196))

### Documentation
* Add arxiv badge to readme ([`7b57aea`](https://github.com/HLasse/TextDescriptives/commit/7b57aeac655d56b21eac96e6a17c9a6c9c16831a))
* Update readme after review and add citation in docs ([`728a0d4`](https://github.com/HLasse/TextDescriptives/commit/728a0d40ab48d5626d733e800fd2208dab97d3f8))
* Add arxiv citation ([`bfab60b`](https://github.com/HLasse/TextDescriptives/commit/bfab60b89e57b101fd4efbb72fefe9a8ca4e7b6d))
* Add `extract_metrics` to docs and readme ([`163bee5`](https://github.com/HLasse/TextDescriptives/commit/163bee57ff5e26718594069564ff0ac8a0e63c47))
* Download spacy model in tutorial ([`96634cb`](https://github.com/HLasse/TextDescriptives/commit/96634cb62008ac18132513e4babbaa04350b1bc0))
* Reset changelog ([`12007b7`](https://github.com/HLasse/TextDescriptives/commit/12007b7d6f72223edd699cfc310ab035830c4ce6))

